@@ -35,6 +35,11 @@ GType tangle_bufferer_get_type(void) G_GNUC_CONST;
 ClutterActor* tangle_bufferer_new(void);
 ClutterActor* tangle_bufferer_new_with_layout(TangleLayout* layout);
 
-void tangle_bufferer_mark_allocation_changed(ClutterActor* actor);
+guint tangle_bufferer_get_n_buffers(TangleBufferer* bufferer);
+void tangle_bufferer_set_n_buffers(TangleBufferer* bufferer, guint n_buffers);
+
+/* TODO: This is temporary hack to enable containers do buffer switching. */
+void tangle_bufferer_begin_paint_actor(ClutterActor* actor);
+void tangle_bufferer_end_paint_actor(ClutterActor* actor);
 
 #endif
