@@ -54,6 +54,8 @@ ClutterAction* tangle_drag_action_new() {
 
 ClutterActor* tangle_drag_action_get_drag_actor(TangleDragAction* drag_action) {
 	ClutterActor* drag_actor;
+
+	g_return_val_if_fail(TANGLE_IS_DRAG_ACTION(drag_action), NULL);
 	
 	if (!(drag_actor = clutter_drag_action_get_drag_handle(CLUTTER_DRAG_ACTION(drag_action)))) {
 		drag_actor = clutter_actor_meta_get_actor(CLUTTER_ACTOR_META(drag_action));
@@ -115,7 +117,10 @@ static void tangle_drag_action_drag_motion(ClutterDragAction* action, ClutterAct
 
 	change_actor_under(drag_action);
 	if (drag_action->priv->drop_action) {
-		tangle_drop_action_drag_motion(drag_action->priv->drop_action, drag_action);
+		if (tangle_drop_action_drag_motion(drag_action->priv->drop_action, drag_action)) {
+			g_object_unref(drag_action->priv->drop_action);
+			drag_action->priv->drop_action = NULL;
+		}
 	}		
 }
 
