@@ -30,6 +30,9 @@ static void tangle_fixed_layout_get_preferred_width(TangleLayout* layout, Tangle
 	min_width = natural_width = 0;
 	for (tangle_widget_initialize_actor_iterator(widget, &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		x = clutter_actor_get_x(actor);
+		if (x < 0) {
+			x = 0;
+		}
 		clutter_actor_get_preferred_size(actor, &min, NULL, &natural, NULL);
 
 		if (x + min > min_width) {
@@ -58,6 +61,9 @@ static void tangle_fixed_layout_get_preferred_height(TangleLayout* layout, Tangl
 	min_height = natural_height = 0;
 	for (tangle_widget_initialize_actor_iterator(widget, &actor_iterator); (actor = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		y = clutter_actor_get_y(actor);
+		if (y < 0) {
+			y = 0;
+		}
 		clutter_actor_get_preferred_size(actor, NULL, &min, NULL, &natural);
 
 		if (y + min > min_height) {
