@@ -54,11 +54,13 @@ ClutterActor* tangle_grid_new_with_line_color(gfloat grid_spacing_x, gfloat grid
 }
 
 gfloat tangle_grid_get_grid_spacing_x(TangleGrid* grid) {
+	g_return_if_fail(TANGLE_IS_GRID(grid));
 
 	return grid->priv->grid_spacing_x;
 }
 
 void tangle_grid_set_grid_spacing_x(TangleGrid* grid, gfloat grid_spacing_x) {
+	g_return_if_fail(TANGLE_IS_GRID(grid));
 	g_return_if_fail(grid_spacing_x >= 0.0);
 
 	if (grid->priv->grid_spacing_x != grid_spacing_x) {
@@ -69,11 +71,13 @@ void tangle_grid_set_grid_spacing_x(TangleGrid* grid, gfloat grid_spacing_x) {
 }
 
 gfloat tangle_grid_get_grid_spacing_y(TangleGrid* grid) {
+	g_return_val_if_fail(TANGLE_IS_GRID(grid), 0.0);
 
 	return grid->priv->grid_spacing_y;
 }
 
 void tangle_grid_set_grid_spacing_y(TangleGrid* grid, gfloat grid_spacing_y) {
+	g_return_if_fail(TANGLE_IS_GRID(grid));
 	g_return_if_fail(grid_spacing_y >= 0.0);
 
 	if (grid->priv->grid_spacing_y != grid_spacing_y) {
@@ -84,11 +88,13 @@ void tangle_grid_set_grid_spacing_y(TangleGrid* grid, gfloat grid_spacing_y) {
 }
 
 guint tangle_grid_get_line_width_x(TangleGrid* grid) {
+	g_return_val_if_fail(TANGLE_IS_GRID(grid), 0);
 
 	return grid->priv->line_width_x;
 }
 
 void tangle_grid_set_line_width_x(TangleGrid* grid, guint line_width_x) {
+	g_return_if_fail(TANGLE_IS_GRID(grid));
 	g_return_if_fail(line_width_x >= 1);
 
 	if (grid->priv->line_width_x != line_width_x) {
@@ -99,11 +105,13 @@ void tangle_grid_set_line_width_x(TangleGrid* grid, guint line_width_x) {
 }
 
 guint tangle_grid_get_line_width_y(TangleGrid* grid) {
+	g_return_val_if_fail(TANGLE_IS_GRID(grid), 0);
 
 	return grid->priv->line_width_y;
 }
 
 void tangle_grid_set_line_width_y(TangleGrid* grid, guint line_width_y) {
+	g_return_if_fail(TANGLE_IS_GRID(grid));
 	g_return_if_fail(line_width_y >= 1);
 
 	if (grid->priv->line_width_y != line_width_y) {
@@ -114,12 +122,15 @@ void tangle_grid_set_line_width_y(TangleGrid* grid, guint line_width_y) {
 }
 
 void tangle_grid_get_background_color(TangleGrid* grid, ClutterColor* color_return) {
+	g_return_if_fail(TANGLE_IS_GRID(grid));
 	g_return_if_fail(color_return != NULL);
 
 	*color_return = grid->priv->background_color;
 }
 
 void tangle_grid_set_background_color(TangleGrid* grid, const ClutterColor* background_color) {
+	g_return_if_fail(TANGLE_IS_GRID(grid));
+
 	if (!clutter_color_equal(&grid->priv->background_color, background_color)) {
 		if (background_color) {
 			grid->priv->background_color = *background_color;
@@ -133,12 +144,15 @@ void tangle_grid_set_background_color(TangleGrid* grid, const ClutterColor* back
 }
 
 void tangle_grid_get_line_color_x(TangleGrid* grid, ClutterColor* color_return) {
+	g_return_if_fail(TANGLE_IS_GRID(grid));
 	g_return_if_fail(color_return != NULL);
 
 	*color_return = grid->priv->line_color_x;
 }
 
 void tangle_grid_set_line_color_x(TangleGrid* grid, const ClutterColor* line_color_x) {
+	g_return_if_fail(TANGLE_IS_GRID(grid));
+
 	if (!clutter_color_equal(&grid->priv->line_color_x, line_color_x)) {
 		if (line_color_x) {
 			grid->priv->line_color_x = *line_color_x;
@@ -152,12 +166,15 @@ void tangle_grid_set_line_color_x(TangleGrid* grid, const ClutterColor* line_col
 }
 
 void tangle_grid_get_line_color_y(TangleGrid* grid, ClutterColor* color_return) {
+	g_return_if_fail(TANGLE_IS_GRID(grid));
 	g_return_if_fail(color_return != NULL);
 
 	*color_return = grid->priv->line_color_y;
 }
 
 void tangle_grid_set_line_color_y(TangleGrid* grid, const ClutterColor* line_color_y) {
+	g_return_if_fail(TANGLE_IS_GRID(grid));
+
 	if (!clutter_color_equal(&grid->priv->line_color_y, line_color_y)) {
 		if (line_color_y) {
 			grid->priv->line_color_y = *line_color_y;
