@@ -51,6 +51,8 @@ TangleProperties* tangle_properties_new(void) {
 GType tangle_properties_get_property_type(TangleProperties* properties, const gchar* name) {
 	GType type = G_TYPE_INVALID;
 	GValue* existing_value;
+
+	g_return_val_if_fail(TANGLE_IS_PROPERTIES(properties), G_TYPE_NONE);
 	
 	existing_value = g_hash_table_lookup(properties->priv->hash_table, name);
 	if (existing_value) {
@@ -64,6 +66,8 @@ gboolean tangle_properties_get_property(TangleProperties* properties, const gcha
 	gboolean found = FALSE;
 	GValue* existing_value;
 	
+	g_return_val_if_fail(TANGLE_IS_PROPERTIES(properties), FALSE);
+
 	existing_value = g_hash_table_lookup(properties->priv->hash_table, name);
 	if (existing_value) {
 		g_value_init(value, G_VALUE_TYPE(existing_value));
@@ -82,6 +86,8 @@ gboolean tangle_properties_get(TangleProperties* properties, const gchar* first_
 	guint i;
 	gchar* error;
 
+	g_return_val_if_fail(TANGLE_IS_PROPERTIES(properties), FALSE);
+
 	name = first_name;
 	type = first_type;
 	va_start(args, first_type);
@@ -111,6 +117,8 @@ gboolean tangle_properties_get_boolean(TangleProperties* properties, const gchar
 	gboolean value = FALSE;
 	GValue* existing_value;
 	
+	g_return_val_if_fail(TANGLE_IS_PROPERTIES(properties), FALSE);
+
 	existing_value = g_hash_table_lookup(properties->priv->hash_table, name);
 	if (!existing_value) {
 		g_critical("No such property: '%s'.", name);
@@ -125,6 +133,8 @@ gint64 tangle_properties_get_int(TangleProperties* properties, const gchar* name
 	gint64 value = 0;
 	GValue* existing_value;
 	
+	g_return_val_if_fail(TANGLE_IS_PROPERTIES(properties), 0);
+
 	existing_value = g_hash_table_lookup(properties->priv->hash_table, name);
 	if (!existing_value) {
 		g_critical("No such property: '%s'.", name);
@@ -139,6 +149,8 @@ double tangle_properties_get_double(TangleProperties* properties, const gchar* n
 	gdouble value = 0.0;
 	GValue* existing_value;
 	
+	g_return_val_if_fail(TANGLE_IS_PROPERTIES(properties), 0.0);
+
 	existing_value = g_hash_table_lookup(properties->priv->hash_table, name);
 	if (!existing_value) {
 		g_critical("No such property: '%s'.", name);
@@ -153,6 +165,8 @@ const gchar* tangle_properties_get_string(TangleProperties* properties, const gc
 	const gchar* value = NULL;
 	GValue* existing_value;
 	
+	g_return_val_if_fail(TANGLE_IS_PROPERTIES(properties), NULL);
+
 	existing_value = g_hash_table_lookup(properties->priv->hash_table, name);
 	if (!existing_value) {
 		g_critical("No such property: '%s'.", name);
@@ -167,6 +181,8 @@ gchar* tangle_properties_dup_string(TangleProperties* properties, const gchar* n
 	gchar* value = NULL;
 	GValue* existing_value;
 	
+	g_return_val_if_fail(TANGLE_IS_PROPERTIES(properties), NULL);
+
 	existing_value = g_hash_table_lookup(properties->priv->hash_table, name);
 	if (!existing_value) {
 		g_critical("No such property: '%s'.", name);
@@ -184,6 +200,8 @@ GParameter* tangle_properties_get_as_parameters(TangleProperties* properties, gu
 	const gchar* name;
 	GValue* value;
 
+	g_return_val_if_fail(TANGLE_IS_PROPERTIES(properties), NULL);
+
 	*n_p = g_hash_table_size(properties->priv->hash_table);
 	parameters = g_new0(GParameter, *n_p);
 	g_hash_table_iter_init(&iter, properties->priv->hash_table);
@@ -238,6 +256,8 @@ void tangle_properties_set_valist(TangleProperties* properties, va_list properti
 	gchar* error;
 
 	while ((name = va_arg(properties_list, const gchar*))) {
+	g_return_if_fail(TANGLE_IS_PROPERTIES(properties));
+
 		type = va_arg(properties_list, GType);
 		g_value_init(&value, type);
 		error = NULL;
@@ -255,6 +275,8 @@ void tangle_properties_set_valist(TangleProperties* properties, va_list properti
 void tangle_properties_set_boolean(TangleProperties* properties, const gchar* name, gboolean boolean_value) {
 	GValue value = { 0 };
 	
+	g_return_if_fail(TANGLE_IS_PROPERTIES(properties));
+
 	g_value_init(&value, G_TYPE_BOOLEAN);
 	g_value_set_boolean(&value, boolean_value);
 	tangle_properties_set_property(properties, name, &value);
@@ -264,6 +286,8 @@ void tangle_properties_set_boolean(TangleProperties* properties, const gchar* na
 void tangle_properties_set_int(TangleProperties* properties, const gchar* name, gint64 int_value) {
 	GValue value = { 0 };
 	
+	g_return_if_fail(TANGLE_IS_PROPERTIES(properties));
+
 	g_value_init(&value, G_TYPE_INT64);
 	g_value_set_int64(&value, int_value);
 	tangle_properties_set_property(properties, name, &value);
@@ -273,6 +297,8 @@ void tangle_properties_set_int(TangleProperties* properties, const gchar* name,
 void tangle_properties_set_double(TangleProperties* properties, const gchar* name, double double_value) {
 	GValue value = { 0 };
 	
+	g_return_if_fail(TANGLE_IS_PROPERTIES(properties));
+
 	g_value_init(&value, G_TYPE_DOUBLE);
 	g_value_set_double(&value, double_value);
 	tangle_properties_set_property(properties, name, &value);
@@ -282,6 +308,8 @@ void tangle_properties_set_double(TangleProperties* properties, const gchar* nam
 void tangle_properties_set_string(TangleProperties* properties, const gchar* name, const gchar* string_value) {
 	GValue value = { 0 };
 	
+	g_return_if_fail(TANGLE_IS_PROPERTIES(properties));
+
 	g_value_init(&value, G_TYPE_STRING);
 	g_value_set_string(&value, string_value);
 	tangle_properties_set_property(properties, name, &value);
@@ -289,6 +317,8 @@ void tangle_properties_set_string(TangleProperties* properties, const gchar* nam
 }
 
 void tangle_properties_foreach(TangleProperties* properties, TanglePropertyCallback callback, gpointer user_data) {
+	g_return_if_fail(TANGLE_IS_PROPERTIES(properties));
+
 	g_hash_table_foreach(properties->priv->hash_table, (GHFunc)callback, user_data);
 }
 
