@@ -50,16 +50,20 @@ ClutterActor* tangle_scrollbar_new_rectangle(gboolean vertical, const ClutterCol
 }
 
 gboolean tangle_scrollbar_get_vertical(TangleScrollbar* scrollbar) {
+	g_return_val_if_fail(TANGLE_IS_SCROLLBAR(scrollbar), FALSE);
 
 	return scrollbar->priv->vertical;
 }
 
 ClutterActor* tangle_scrollbar_get_bar_actor(TangleScrollbar* scrollbar) {
+	g_return_val_if_fail(TANGLE_IS_SCROLLBAR(scrollbar), NULL);
 
 	return scrollbar->priv->bar_actor;
 }
 
 void tangle_scrollbar_set_bar_actor(TangleScrollbar* scrollbar, ClutterActor* bar_actor) {
+	g_return_if_fail(TANGLE_IS_SCROLLBAR(scrollbar));
+
 	if (scrollbar->priv->bar_actor != bar_actor) {
 		if (scrollbar->priv->bar_actor) {
 			clutter_container_remove_actor(CLUTTER_CONTAINER(scrollbar), scrollbar->priv->bar_actor);
@@ -70,30 +74,6 @@ void tangle_scrollbar_set_bar_actor(TangleScrollbar* scrollbar, ClutterActor* ba
 	}
 }
 
-void tangle_scrollbar_bind_to_scrolling_actor(TangleScrollbar* scrollbar, TangleScrollingActor* scrolling_actor) {
-	if (scrollbar->priv->vertical) {
-		tangle_binding_new(G_OBJECT(scrollbar), "bar-offset", G_OBJECT(scrolling_actor), "scrolling-offset-y");
-		tangle_binding_new(G_OBJECT(scrollbar), "bar-size", G_OBJECT(scrolling_actor), "height");
-		tangle_binding_new(G_OBJECT(scrollbar), "total-size", G_OBJECT(scrolling_actor), "scrolling-height");			
-	} else {
-		tangle_binding_new(G_OBJECT(scrollbar), "bar-offset", G_OBJECT(scrolling_actor), "scrolling-offset-x");
-		tangle_binding_new(G_OBJECT(scrollbar), "bar-size", G_OBJECT(scrolling_actor), "width");
-		tangle_binding_new(G_OBJECT(scrollbar), "total-size", G_OBJECT(scrolling_actor), "scrolling-width");		
-	}
-}
-
-void tangle_scrollbar_bind_to_scroller(TangleScrollbar* scrollbar, TangleScroller* scroller) {
-	if (scrollbar->priv->vertical) {
-		tangle_binding_new(G_OBJECT(scrollbar), "bar-offset", G_OBJECT(scroller), "scrolling-offset-y");
-		tangle_binding_new(G_OBJECT(scrollbar), "bar-size", G_OBJECT(scroller), "height");
-		tangle_binding_new(G_OBJECT(scrollbar), "total-size", G_OBJECT(scroller), "scrolling-height");			
-	} else {
-		tangle_binding_new(G_OBJECT(scrollbar), "bar-offset", G_OBJECT(scroller), "scrolling-offset-x");
-		tangle_binding_new(G_OBJECT(scrollbar), "bar-size", G_OBJECT(scroller), "width");
-		tangle_binding_new(G_OBJECT(scrollbar), "total-size", G_OBJECT(scroller), "scrolling-width");		
-	}
-}
-
 static void tangle_scrollbar_allocate(ClutterActor* actor, const ClutterActorBox* box, ClutterAllocationFlags flags) {
 	TangleScrollbar* scrollbar;
 	gfloat size;
