@@ -66,15 +66,17 @@ TangleStylesheet* tangle_stylesheet_new_from_file(const gchar* name) {
 	}
 	
 	return stylesheet;
-
 }
 
 GList* tangle_stylesheet_get_styles(TangleStylesheet* stylesheet) {
+	g_return_val_if_fail(TANGLE_IS_STYLESHEET(stylesheet), NULL);
 
 	return g_list_copy(stylesheet->priv->styles);
 }
 
 void tangle_stylesheet_add_style(TangleStylesheet* stylesheet, TangleStyle* style) {
+	g_return_if_fail(TANGLE_IS_STYLESHEET(stylesheet));
+
 	if (!g_list_find(stylesheet->priv->styles, style)) {
 		g_signal_emit(stylesheet, signals[STYLE_ADDED], 0, style);
 		g_object_ref(style);
@@ -82,6 +84,8 @@ void tangle_stylesheet_add_style(TangleStylesheet* stylesheet, TangleStyle* styl
 }
 
 void tangle_stylesheet_remove_style(TangleStylesheet* stylesheet, TangleStyle* style) {
+	g_return_if_fail(TANGLE_IS_STYLESHEET(stylesheet));
+
 	if (g_list_find(stylesheet->priv->styles, style)) {
 		g_signal_emit(stylesheet, signals[STYLE_REMOVED], 0, style);
 		g_object_unref(style);
@@ -92,6 +96,8 @@ void tangle_stylesheet_apply(TangleStylesheet* stylesheet, GObject* object) {
 	gboolean handled = FALSE;
 	TangleStyle* style;
 
+	g_return_if_fail(TANGLE_IS_STYLESHEET(stylesheet));
+
 	if (TANGLE_IS_STYLABLE(object)) {
 		handled = tangle_stylable_apply_stylesheet(TANGLE_STYLABLE(object), stylesheet);
 	}
@@ -106,6 +112,8 @@ void tangle_stylesheet_unapply(TangleStylesheet* stylesheet, GObject* object) {
 	gboolean handled = FALSE;
 	TangleStyle* style;
 
+	g_return_if_fail(TANGLE_IS_STYLESHEET(stylesheet));
+
 	if (TANGLE_IS_STYLABLE(object)) {
 		handled = tangle_stylable_unapply_stylesheet(TANGLE_STYLABLE(object), stylesheet);
 	}
@@ -121,6 +129,8 @@ TangleStyle* tangle_stylesheet_get_style_for_object(TangleStylesheet* stylesheet
 	GList* style_in_list;
 	TangleStyle* style;
 	
+	g_return_val_if_fail(TANGLE_IS_STYLESHEET(stylesheet), NULL);
+
 	/* TODO: This can be optimized so that compound style is created only when really needed. */
 	compound_style = tangle_compound_style_new_with_stylesheet(G_OBJECT_TYPE(object), stylesheet);
 	for (style_in_list = stylesheet->priv->styles; style_in_list; style_in_list = style_in_list->next) {
@@ -143,6 +153,8 @@ TangleStylesheet* tangle_stylesheet_get_default() {
 }
 
 void tangle_stylesheet_set_default(TangleStylesheet* stylesheet) {
+	g_return_if_fail(TANGLE_IS_STYLESHEET(stylesheet));
+
 	if (default_stylesheet) {
 		g_object_unref(default_stylesheet);
 	}
