@@ -13,6 +13,7 @@
 #include "tangle-misc.h"
 #include "tangle-scroll-action.h"
 #include "tangle-scroll-trick.h"
+#include "tangle-bufferer.h"
 
 /**
  * SECTION:tangle-widget
@@ -564,7 +565,10 @@ static void paint_actor(gpointer data, gpointer user_data) {
 	actor = CLUTTER_ACTOR(data);
 	
 	if (CLUTTER_ACTOR_IS_MAPPED(actor)) {
+		/* TODO: This is a hack to do buffering before effects. */
+		tangle_bufferer_begin_paint_actor(actor);
 		clutter_actor_paint(actor);
+		tangle_bufferer_end_paint_actor(actor);
 	}
 }
 
@@ -841,7 +845,7 @@ static void tangle_widget_map(ClutterActor* actor) {
 	if (widget->priv->background_actor && widget->priv->background_parented) {
 		clutter_actor_map(widget->priv->background_actor);
 	}
-	if (widget->priv->foreground_actor && widget->priv->background_parented) {
+	if (widget->priv->foreground_actor && widget->priv->foreground_parented) {
 		clutter_actor_map(widget->priv->foreground_actor);
 	}
 }
@@ -855,7 +859,7 @@ static void tangle_widget_unmap(ClutterActor* actor) {
 	if (widget->priv->background_actor && widget->priv->background_parented) {
 		clutter_actor_unmap(widget->priv->background_actor);
 	}
-	if (widget->priv->foreground_actor && widget->priv->background_parented) {
+	if (widget->priv->foreground_actor && widget->priv->foreground_parented) {
 		clutter_actor_unmap(widget->priv->foreground_actor);
 	}
 
