@@ -31,8 +31,8 @@ int main(int argc, char** argv) {
 
 	/* Clickable button */
 
-	normal_texture = clutter_texture_new_from_file("test_image_100x74.jpg", NULL);
-	active_texture = clutter_texture_new_from_file("test_image_135x100.jpg", NULL);
+	normal_texture = tangle_texture_new("test_image_100x74.jpg");
+	active_texture = tangle_texture_new("test_image_135x100.jpg");
 
 	clickable_button = tangle_button_new_with_background_actors(normal_texture, active_texture);
 	clutter_actor_set_position(clickable_button, 100.0, 100.0);
@@ -41,9 +41,9 @@ int main(int argc, char** argv) {
 
 	/* Selectable button */
 
-	normal_texture = clutter_texture_new_from_file("test_image_100x74.jpg", NULL);
-	active_texture = clutter_texture_new_from_file("test_image_135x100.jpg", NULL);
-	selected_texture = clutter_texture_new_from_file("test_image_selected_100x74.jpg", NULL);
+	normal_texture = tangle_texture_new("test_image_100x74.jpg");
+	active_texture = tangle_texture_new("test_image_135x100.jpg");
+	selected_texture = tangle_texture_new("test_image_selected_100x74.jpg");
 
 	selectable_button = tangle_button_new_selectable_with_background_actors(normal_texture, active_texture, selected_texture);
 	tangle_button_set_selected(TANGLE_BUTTON(selectable_button), TRUE);
@@ -52,9 +52,9 @@ int main(int argc, char** argv) {
 
 	/* Radio button alone */
 
-	normal_texture = clutter_texture_new_from_file("test_image_100x74.jpg", NULL);
-	active_texture = clutter_texture_new_from_file("test_image_135x100.jpg", NULL);
-	selected_texture = clutter_texture_new_from_file("test_image_selected_100x74.jpg", NULL);
+	normal_texture = tangle_texture_new("test_image_100x74.jpg");
+	active_texture = tangle_texture_new("test_image_135x100.jpg");
+	selected_texture = tangle_texture_new("test_image_selected_100x74.jpg");
 
 	radio_button = tangle_button_new_radio_with_background_actors(normal_texture, active_texture, selected_texture);
 	clutter_actor_set_position(radio_button, 300.0, 300.0);
@@ -62,25 +62,25 @@ int main(int argc, char** argv) {
 	
 	/* Radio buttons for a group */
 	
-	normal_texture = clutter_texture_new_from_file("test_image_100x74.jpg", NULL);
-	active_texture = clutter_texture_new_from_file("test_image_135x100.jpg", NULL);
-	selected_texture = clutter_texture_new_from_file("test_image_selected_100x74.jpg", NULL);
+	normal_texture = tangle_texture_new("test_image_100x74.jpg");
+	active_texture = tangle_texture_new("test_image_135x100.jpg");
+	selected_texture = tangle_texture_new("test_image_selected_100x74.jpg");
 
 	radio_button1 = tangle_button_new_radio_with_background_actors(normal_texture, active_texture, selected_texture);
 	clutter_actor_set_position(radio_button1, 300.0, 100.0);
 	g_signal_connect(radio_button1, "clicked", G_CALLBACK(on_clicked), NULL);
 
-	normal_texture = clutter_texture_new_from_file("test_image_100x74.jpg", NULL);
-	active_texture = clutter_texture_new_from_file("test_image_135x100.jpg", NULL);
-	selected_texture = clutter_texture_new_from_file("test_image_selected_100x74.jpg", NULL);
+	normal_texture = tangle_texture_new("test_image_100x74.jpg");
+	active_texture = tangle_texture_new("test_image_135x100.jpg");
+	selected_texture = tangle_texture_new("test_image_selected_100x74.jpg");
 
 	radio_button2 = tangle_button_new_radio_with_background_actors(normal_texture, active_texture, selected_texture);
 	clutter_actor_set_position(radio_button2, 450.0, 100.0);
 	g_signal_connect(radio_button2, "clicked", G_CALLBACK(on_clicked), NULL);
 
-	normal_texture = clutter_texture_new_from_file("test_image_100x74.jpg", NULL);
-	active_texture = clutter_texture_new_from_file("test_image_135x100.jpg", NULL);
-	selected_texture = clutter_texture_new_from_file("test_image_selected_100x74.jpg", NULL);
+	normal_texture = tangle_texture_new("test_image_100x74.jpg");
+	active_texture = tangle_texture_new("test_image_135x100.jpg");
+	selected_texture = tangle_texture_new("test_image_selected_100x74.jpg");
 
 	radio_button3 = tangle_button_new_radio_with_background_actors(normal_texture, active_texture, selected_texture);
 	clutter_actor_set_position(radio_button3, 600.0, 100.0);
