@@ -20,7 +20,7 @@ int main(int argc, char** argv) {
 	clutter_actor_set_position(widget, 100.0, 100.0);
 	clutter_container_add_actor(CLUTTER_CONTAINER(stage), widget);
 	
-	texture1 = clutter_texture_new_from_file("test_image_100x74.jpg", NULL);
+	texture1 = tangle_texture_new("test_image_100x74.jpg");
 	clutter_actor_set_position(texture1, 0.0, 0.0);
 
 	/* Texture2 is actually TangleWrapperActor, because we need
@@ -29,13 +29,13 @@ int main(int argc, char** argv) {
 
 /* TODO: The TangleWrapperActor does not exist any more.
 
-	texture2 = tangle_wrapper_actor_new(clutter_texture_new_from_file("test_image_selected_100x74.jpg", NULL));
+	texture2 = tangle_wrapper_actor_new(tangle_texture_new("test_image_selected_100x74.jpg"));
 	clutter_actor_set_position(texture2, 33.0, 33.0);
 	tangle_actor_set_depth_position(TANGLE_ACTOR(texture2), -100);
 
 */
 
-	texture3 = clutter_texture_new_from_file("test_image_100x74.jpg", NULL);
+	texture3 = tangle_texture_new("test_image_100x74.jpg");
 	clutter_actor_set_position(texture3, 66.0, 66.0);
 
 	clutter_container_add(CLUTTER_CONTAINER(widget), texture1, /* TODO: texture2, */ texture3, NULL);
