@@ -21,7 +21,7 @@ int main(int argc, char** argv) {
 	stage = clutter_stage_get_default();
 	clutter_actor_set_size(stage, 800.0, 400.0);
 
-	actor = clutter_texture_new_from_file("test_image_100x74.jpg", NULL);
+	actor = tangle_texture_new("test_image_100x74.jpg");
 	clutter_actor_set_reactive(actor, TRUE);
 	
 	action = tangle_hold_action_new();
