@@ -28,7 +28,7 @@ int main(int argc, char** argv) {
 	clutter_actor_set_reactive(widget, TRUE);
 //	for (x = 0; x < 20; x++) {
 		for (y = 0; y < 10; y++) {
-			texture = clutter_texture_new_from_file("test_image_135x100.jpg", NULL);
+			texture = tangle_texture_new("test_image_135x100.jpg");
 			wrapper = texture; //tangle_wrapper_actor_new(texture);
 
 			if (y == 2) {
